vk2dfd

Function vk2dfd 

pub fn vk2dfd(vulkan_format: VkFormat) -> Result<&'static [u32], Error>
Converts a Vulkan format to the appropriate descriptor.

Returns the descriptor as a static slice of u32s, or an Error on failure. If written to a KTX or KTX2 file, the descriptor must be written in little endian byte order per the specification. The slice includes the leading size word.